NAME
Goo::TextUtilities - Miscellaneous utilities for handling text
SYNOPSIS
use Goo::TextUtilities;
DESCRIPTION
METHODS
- get_hostname
-
return a hostname from the url
-
strip all href tags
- uppercase_first_letters
-
turn the first letters of each word into uppercase
- escape_url
-
escape a url string
- strip_funky_html
-
strip any html that is too funky for a normal tag strip
- strip_html
-
strip the html from a string
- trim_whitespace
-
strip whitespace from the front and back of a string
- compress_whitespace
-
compress excess whitespace from many to 1 space
- right_pad
-
pad a string on the righthand side up to a maximum
- strip_last_word
-
strip the last word off the end of a string
- left_pad
-
pad a string on the lefthand side up to a maximum
- truncate_string
-
reduce the size of the string and remove the last word
- escape_javascript
-
escape double quotes etc.
- get_matching_line_number
-
return the linenumber that matches the regex
AUTHOR
Nigel Hamilton <nigel@turbo10.com>